==> lightnovel_crawler-2.24.5-py3-none-any.whl: lncrawl/sources/novelringan.py <==
# -*- coding: utf-8 -*-
import json
import logging
import re
from ..utils.crawler import Crawler

logger = logging.getLogger(__name__)


class NovelRinganCrawler(Crawler):
    base_url = 'https://novelringan.com/'

    def read_novel_info(self):
        '''Get novel title, autor, cover etc'''
        logger.debug('Visiting %s', self.novel_url)
        soup = self.get_soup(self.novel_url)

        self.novel_title = soup.select_one('h1.entry-title').text
        logger.info('Novel title: %s', self.novel_title)

        self.novel_cover = self.absolute_url(
            soup.select_one('div.imgprop img')['src'])
        logger.info('Novel cover: %s', self.novel_cover)

        self.novel_author = 'Translated by novelringan.com'
        logger.info('Novel author: %s', self.novel_author)

        for a in reversed(soup.select('.bxcl ul li a')):
            chap_id = len(self.chapters) + 1
            if len(self.chapters) % 100 == 0:
                vol_id = chap_id//100 + 1
                vol_title = 'Volume ' + str(vol_id)
                self.volumes.append({
                    'id': vol_id,
                    'title': vol_title,
                })
            # end if
            self.chapters.append({
                'id': chap_id,
                'volume': vol_id,
                'url':  self.absolute_url(a['href']),
                'title': a.text.strip() or ('Chapter %d' % chap_id),
            })
        # end for
    # end def

    def download_chapter_body(self, chapter):
        '''Download body of a single chapter and return as clean html format.'''
        logger.info('Downloading %s', chapter['url'])
        soup = self.get_soup(chapter['url'])

        soup.select_one('#bacotan').extract()
        contents = soup.select('.entry-content p')

        body = [str(p) for p in contents if p.text.strip()]

        return '<p>' + '</p><p>'.join(body) + '</p>'

    # end def
# end class

==> lightnovel_crawler-2.26.5-py3-none-any.whl: lncrawl/sources/novelringan.py <==
# -*- coding: utf-8 -*-
import json
import logging
import re
from ..utils.crawler import Crawler

logger = logging.getLogger(__name__)


class NovelRinganCrawler(Crawler):
    base_url = 'https://novelringan.com/'

    def read_novel_info(self):
        '''Get novel title, autor, cover etc'''
        logger.debug('Visiting %s', self.novel_url)
        soup = self.get_soup(self.novel_url)

        self.novel_title = soup.select_one('h1.entry-title').text
        logger.info('Novel title: %s', self.novel_title)

        self.novel_cover = self.absolute_url(
            soup.select_one('div.imgprop img')['src'])
        logger.info('Novel cover: %s', self.novel_cover)

        self.novel_author = " ".join(
            [
                a.text.strip()
                for a in soup.select('.entry-author a[href*="/author/"]')
            ]
        )
        logger.info("%s", self.novel_author)

        for a in reversed(soup.select('.bxcl ul li a')):
            chap_id = len(self.chapters) + 1
            if len(self.chapters) % 100 == 0:
                vol_id = chap_id//100 + 1
                vol_title = 'Volume ' + str(vol_id)
                self.volumes.append({
                    'id': vol_id,
                    'title': vol_title,
                })
            # end if
            self.chapters.append({
                'id': chap_id,
                'volume': vol_id,
                'url':  self.absolute_url(a['href']),
                'title': a.text.strip() or ('Chapter %d' % chap_id),
            })
        # end for
    # end def

    def download_chapter_body(self, chapter):
        '''Download body of a single chapter and return as clean html format.'''
        logger.info('Downloading %s', chapter['url'])
        soup = self.get_soup(chapter['url'])
        chapter['body_lock'] = True
        contents = soup.select('.entry-content p')

        body = [str(p) for p in contents if p.text.strip()]

        return '<p>' + '</p><p>'.join(body) + '</p>'

    # end def
# end class
